@@ -2,7 +2,7 @@ package PAR::Dist;
 require Exporter;
 use vars qw/$VERSION @ISA @EXPORT @EXPORT_OK/;
 
-$VERSION    = '0.21';
+$VERSION    = '0.24';
 @ISA	    = 'Exporter';
 @EXPORT	    = qw/
   blib_to_par
@@ -18,6 +18,7 @@ $VERSION    = '0.21';
 
 @EXPORT_OK = qw/
   parse_dist_name
+  contains_binaries
 /;
 
 use strict;
@@ -30,7 +31,7 @@ PAR::Dist - Create and manipulate PAR distributions
 
 =head1 VERSION
 
-This document describes version 0.20 of PAR::Dist, released Oct 11, 2006.
+This document describes version 0.24 of PAR::Dist, released Jul 20, 2007.
 
 =head1 SYNOPSIS
 
@@ -138,8 +139,11 @@ sub blib_to_par {
     my %args = @_;
     require Config;
 
+
+    # don't use 'my $foo ... if ...' it creates a static variable!
+    my $dist;
     my $path	= $args{path};
-    my $dist	= File::Spec->rel2abs($args{dist}) if $args{dist};
+    $dist	= File::Spec->rel2abs($args{dist}) if $args{dist};
     my $name	= $args{name};
     my $version	= $args{version};
     my $suffix	= $args{suffix} || "$Config::Config{archname}-$Config::Config{version}.par";
@@ -927,7 +931,8 @@ Math-Symbolic-0.502-x86_64-linux-gnu-thread-multi-5.8.7
 Math-Symbolic-0.502
 
 The ".tar.gz" or ".par" extensions as well as any
-preceding paths are stripped before parsing.
+preceding paths are stripped before parsing. Starting with C<PAR::Dist>
+0.22, versions containing a preceding C<v> are parsed correctly.
 
 This function is not exported by default.
 
@@ -939,13 +944,20 @@ sub parse_dist_name {
 
 	(undef, undef, $file) = File::Spec->splitpath($file);
 	
-	my $version = qr/\d+(?:_\d+)?|\d*(?:\.\d+(?:_\d+)?)+/;
+	my $version = qr/v?(?:\d+(?:_\d+)?|\d*(?:\.\d+(?:_\d+)?)+)/;
 	$file =~ s/\.(?:par|tar\.gz|tar)$//i;
 	my @elem = split /-/, $file;
 	my (@dn, $dv, @arch, $pv);
 	while (@elem) {
 		my $e = shift @elem;
-		if ($e =~ /^$version$/o) {
+		if (
+            $e =~ /^$version$/o
+            and not(# if not next token also a version
+                    # (assumes an arch string doesnt start with a version...)
+                @elem and $elem[0] =~ /^$version$/o
+            )
+        ) {
+            
 			$dv = $e;
 			last;
 		}
@@ -1053,6 +1065,58 @@ YAML
 }
 
 
+=head2 contains_binaries
+
+This function is not exported by default.
+
+Opens a PAR archive tries to determine whether that archive
+contains platform-specific binary code.
+
+Takes one named parameter: I<dist>. If only one parameter is
+passed, it is treated as the I<dist> parameter. (Have a look
+at the description in the C<FUNCTIONS> section above.)
+
+Throws a fatal error if the PAR archive could not be found.
+
+Returns one if the PAR was found to contain binary code
+and zero otherwise.
+
+=cut
+
+sub contains_binaries {
+    require File::Find;
+    my %args = &_args;
+    my $dist = $args{dist};
+    return undef if not defined $dist or not -r $dist;
+    require Cwd;
+    require File::Path;
+
+    # The unzipping will change directories. Remember old dir.
+    my $old_cwd = Cwd::cwd();
+    
+    # Unzip the base par to a temp. dir.
+    (undef, my $base_dir) = _unzip_to_tmpdir(
+        dist => $dist, subdir => 'blib'
+    );
+    my $blibdir = File::Spec->catdir($base_dir, 'blib');
+    my $archdir = File::Spec->catdir($blibdir, 'arch');
+
+    my $found = 0;
+
+    File::Find::find(
+      sub {
+        $found++ if -f $_ and not /^\.exists$/;
+      },
+      $archdir
+    );
+
+    chdir($old_cwd);
+    
+    File::Path::rmtree([$base_dir]);
+    
+    return $found ? 1 : 0;
+}
+
 1;
 
 =head1 SEE ALSO
@@ -1061,9 +1125,9 @@ L<PAR>, L<ExtUtils::Install>, L<Module::Signature>, L<LWP::Simple>
 
 =head1 AUTHORS
 
-Audrey Tang E<lt>cpan@audreyt.orgE<gt> 2003-2006
+Audrey Tang E<lt>cpan@audreyt.orgE<gt> 2003-2007
 
-Steffen Mueller E<lt>smueller@cpan.orgE<gt> 2005-2006
+Steffen Mueller E<lt>smueller@cpan.orgE<gt> 2005-2007
 
 PAR has a mailing list, E<lt>par@perl.orgE<gt>, that you can write to;
 send an empty mail to E<lt>par-subscribe@perl.orgE<gt> to join the list
@@ -1073,7 +1137,7 @@ Please send bug reports to E<lt>bug-par@rt.cpan.orgE<gt>.
 
 =head1 COPYRIGHT
 
-Copyright 2003, 2004, 2006 by Audrey Tang E<lt>autrijus@autrijus.orgE<gt>.
+Copyright 2003-2007 by Audrey Tang E<lt>autrijus@autrijus.orgE<gt>.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
